doapfiend.plugins.homepage

Package doapfiend :: Package plugins :: Module homepage |
[hide private]
[frames] | no frames]

# Module homepage

source code

# homepage

Fetches DOAP by searching doapspace.org by a project's homepage.

Classes | [hide private]
| OutputPlugin Class for formatting DOAP output

Functions | [hide private]
unicode |
do_search(homepage) Get DOAP given a project's homepage | source code

Variables | [hide private]
| LOG = `logging.getLogger('doapfiend')`

Function Details | [hide private]

### do_search(homepage) | source code
Get DOAP given a project's homepage Parameters: `homepage` - Project homepage URL Returns: unicode DOAP